Documentation
¶
Index ¶
Constants ¶
const ( // Keep browser DERP/WebSocket packets close to real WireGuard packet // sizing. Public DERP accepts larger theoretical packets, but browser // WebSocket connections have been observed to close on near-64KiB frames. MaxRelayPayloadBytes = 16 << 10 // WebRTC direct payloads can be larger than relay payloads. Keeping this // below common SCTP message-size limits reduces WASM/JS crossings without // relying on jumbo DataChannel messages. MaxPayloadBytes = 128 << 10 )
Variables ¶
var ( ErrInvalidFrame = errors.New("invalid web relay frame") ErrPayloadTooLarge = errors.New("web relay frame payload too large") )
Functions ¶
func IsWebFrame ¶
Types ¶
type DirectFailed ¶
type DirectFailed struct {
Reason string `json:"reason,omitempty"`
}
type DirectReady ¶
type PathSwitch ¶
type WebRTCSignal ¶
type WebRTCSignal struct {
Lane int `json:"lane,omitempty"`
Kind string `json:"kind"`
Type string `json:"type"`
SDP string `json:"sdp,omitempty"`
Candidate string `json:"candidate,omitempty"`
SDPMid string `json:"sdpMid,omitempty"`
SDPMLineIndex int `json:"sdpMLineIndex,omitempty"`
UsernameFragment string `json:"usernameFragment,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.